summaryrefslogtreecommitdiffstats
path: root/akregator/src/librss/article.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/librss/article.h')
-rw-r--r--akregator/src/librss/article.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/akregator/src/librss/article.h b/akregator/src/librss/article.h
index 74deb2539..4aa11850a 100644
--- a/akregator/src/librss/article.h
+++ b/akregator/src/librss/article.h
@@ -11,7 +11,7 @@
#ifndef LIBRSS_ARTICLE_H
#define LIBRSS_ARTICLE_H
-#include <qmap.h>
+#include <tqmap.h>
#include "global.h"
@@ -40,7 +40,7 @@ namespace RSS
/**
* A list of articles.
*/
- typedef QValueList<Article> List;
+ typedef TQValueList<Article> List;
/**
* Default constructor.
@@ -55,10 +55,10 @@ namespace RSS
/**
* Constructs an Article from a piece of RSS markup.
* @param node A QDomNode which references the DOM leaf to be used
* for constructing the Article.
*/
- Article(const QDomNode &node, Format format, Version version);
+ Article(const TQDomNode &node, Format format, Version version);
/**
* Assignment operator.
@@ -90,10 +90,10 @@ namespace RSS
/**
* RSS 0.90 and upwards
* @return The headline of this article, or QString::null if
* no headline was available.
*/
- QString title() const;
+ TQString title() const;
/**
* RSS 0.90 and upwards
@@ -106,25 +106,25 @@ namespace RSS
/**
* RSS 0.91 and upwards
* @return A story synopsis, or QString::null if no description
* was available.
*/
- QString description() const;
+ TQString description() const;
/**
* a string desribing the author of the item.
*/
- QString author() const;
+ TQString author() const;
/**
* RSS 2.0 and upwards
* @return An article GUID (globally unique identifier).
*/
- QString guid() const;
+ TQString guid() const;
/**
* RSS 2.0 and upwards
* @return If this article GUID is permalink. Has no meaning when guid() is QString::null.
*/
bool guidIsPermaLink() const;
@@ -132,7 +132,7 @@ namespace RSS
* RSS 2.0 and upwards
* @return The date when the article was published.
*/
- const QDateTime &pubDate() const;
+ const TQDateTime &pubDate() const;
const KURL &commentsLink() const;
int comments() const;
@@ -140,9 +140,9 @@ namespace RSS
Enclosure enclosure() const;
/** returns a list of categories this article is assigned to. (RSS2 only, Atom is not supported yet) */
- QValueList<Category> categories() const;
+ TQValueList<Category> categories() const;
- QString meta(const QString &key) const;
+ TQString meta(const TQString &key) const;
/**
* @param parent The parent widget for the KURLLabel.
@@ -151,16 +151,16 @@ namespace RSS
* This makes building a user-interface which contains the
* information in this Article object more convenient.
* The returned KURLLabel's caption will be the title(), clicking
- * on it will emit the URL link(), and it has a QToolTip attached
+ * on it will emit the URL link(), and it has a TQToolTip attached
* to it which displays the description() (in case it has one,
* if there is no description, the URL which the label links to
* will be used).
* Note that you have to delete the KURLLabel object returned by
* this method yourself.
*/
- KURLLabel *widget(QWidget *parent = 0, const char *name = 0) const;
+ KURLLabel *widget(TQWidget *parent = 0, const char *name = 0) const;
- typedef QMap<QString, QString> MetaInfoMap;
+ typedef TQMap<TQString, TQString> MetaInfoMap;
private:
struct Private;
@@ -55,10 +55,10 @@ namespace RSS
/**
* Constructs an Article from a piece of RSS markup.
- * @param node A QDomNode which references the DOM leaf to be used
+ * @param node A TQDomNode which references the DOM leaf to be used
* for constructing the Article.
*/
@@ -90,10 +90,10 @@ namespace RSS
/**
* RSS 0.90 and upwards
- * @return The headline of this article, or QString::null if
+ * @return The headline of this article, or TQString::null if
* no headline was available.
*/
@@ -106,25 +106,25 @@ namespace RSS
/**
* RSS 0.91 and upwards
- * @return A story synopsis, or QString::null if no description
+ * @return A story synopsis, or TQString::null if no description
* was available.
*/
@@ -106,25 +106,25 @@ namespace RSS
/**
* RSS 2.0 and upwards
- * @return If this article GUID is permalink. Has no meaning when guid() is QString::null.
+ * @return If this article GUID is permalink. Has no meaning when guid() is TQString::null.
*/
bool guidIsPermaLink() const;